@@ -4,7 +4,7 @@
 function(r,colors=FALSE, n=10,main=NULL,zlim=c(0,1)){
 
 if(is.null(main)) {main <- "Correlation plot" }
-if(!is.matrix(r)) {if((length(class(r)) > 1) & (class(r)[1] =="psych"))  {if(class(r)[2] =="omega") {r <- r$schmid$sl
+if(!is.matrix(r) & (!is.data.frame(r))) {if((length(class(r)) > 1) & (class(r)[1] =="psych"))  {if(class(r)[2] =="omega") {r <- r$schmid$sl
 nff <- ncol(r)
 r <- r[,1:(nff-2)]}  else {r <- r$loadings}
 } }
