@@ -7,6 +7,8 @@ function(x, y, digits=2, prefix="", cex.cor)
          txt <- format(c(r, 0.123456789), digits=digits)[1]
          txt <- paste(prefix, txt, sep="")
          if(missing(cex.cor)) cex <- 0.8/strwidth(txt)
-         text(0.5, 0.5, txt, cex = cex * abs(r))
+         cex1 <- cex  * abs(r)
+         if(cex1 < .25) cex1 <- .25 #otherwise they just vanish
+         text(0.5, 0.5, txt, cex = cex1)
      }
 
